@@ -7,6 +7,7 @@ from typing import IO, Any, AnyStr, Callable, Iterable, Optional, Sequence, Type
 
 import click
 import pluggy
+import tomli_w
 from robotcode.core.dataclasses import as_dict, as_json
 
 __all__ = [
@@ -108,19 +109,13 @@ class Application:
 
         text = None
         if format == OutputFormat.TOML:
-            try:
-                import tomli_w
-
-                text = tomli_w.dumps(
-                    as_dict(data, remove_defaults=remove_defaults)
-                    if dataclasses.is_dataclass(data)
-                    else data
-                    if isinstance(data, dict)
-                    else {data: data}
-                )
-            except ImportError:
-                self.warning("Package 'tomli_w' is required to use TOML output. Using JSON format instead.")
-                format = OutputFormat.JSON
+            text = tomli_w.dumps(
+                as_dict(data, remove_defaults=remove_defaults)
+                if dataclasses.is_dataclass(data)
+                else data
+                if isinstance(data, dict)
+                else {data: data}
+            )
 
         if text is None:
             if format in [OutputFormat.JSON, OutputFormat.JSON_INDENT]:
@@ -176,9 +171,24 @@ class Application:
         if self.colored:
             try:
                 from rich.console import Console, ConsoleOptions, RenderResult
-                from rich.markdown import Heading, Markdown
+                from rich.markdown import (
+                    Heading,
+                    Markdown,
+                    TableBodyElement,
+                    TableDataElement,
+                    TableElement,
+                    TableHeaderElement,
+                    TableRowElement,
+                )
                 from rich.text import Text
 
+                # this is needed because of https://github.com/Textualize/rich/issues/3027
+                TableElement.new_line = False
+                TableHeaderElement.new_line = False
+                TableBodyElement.new_line = False
+                TableRowElement.new_line = False
+                TableDataElement.new_line = False
+
                 class MyHeading(Heading):
                     def __rich_console__(self, console: Console, options: ConsoleOptions) -> RenderResult:
                         for result in super().__rich_console__(console, options):
@@ -220,11 +230,11 @@ class Application:
 
     def keyboard_interrupt(self) -> None:
         self.verbose("Aborted!", file=sys.stderr)
-        raise SystemExit(253)
+        sys.exit(253)
 
     def exit(self, code: int = 0) -> None:
         self.verbose(f"Exit with code {code}")
-        raise SystemExit(code)
+        sys.exit(code)
 
 
 pass_application = click.make_pass_decorator(Application, ensure=True)
